@@ -44,7 +44,7 @@ func init() {
 		RequiredTypes:  []string{{.RequiredTypes}},
 		RequiredLabels: []string{{.RequiredLabels}},
 		DefaultSeverity: severity.Warning, //TODO set the default severity
-		CheckFunc: func(set result.Set, block *block.Block, _ *hclcontext.Context){
+		CheckFunc: func(set result.Set, block block.Block, _ *hclcontext.Context){
 				
 			// function contents here
 
